# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agent.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'agent.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61gent.proto\x12\x05\x61gent\x1a\x1cgoogle/protobuf/struct.proto\"\x1b\n\x0bTextContent\x12\x0c\n\x04text\x18\x01 \x01(\t\"h\n\x0cImageContent\x12\x12\n\nimage_data\x18\x01 \x01(\x0c\x12\x14\n\x07\x63\x61ption\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66ilename\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_captionB\x0b\n\t_filename\"h\n\x0cVideoContent\x12\x12\n\nvideo_data\x18\x01 \x01(\x0c\x12\x14\n\x07\x63\x61ption\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66ilename\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_captionB\x0b\n\t_filename\"F\n\x0c\x41udioContent\x12\x12\n\naudio_data\x18\x01 \x01(\x0c\x12\x15\n\x08\x66ilename\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_filename\"H\n\x0f\x44ocumentContent\x12\x11\n\tfile_data\x18\x01 \x01(\x0c\x12\x15\n\x08\x66ilename\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_filename\"6\n\x0fLocationContent\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\"N\n\x0cInlineButton\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x17\n\rcallback_data\x18\x02 \x01(\tH\x00\x12\r\n\x03url\x18\x03 \x01(\tH\x00\x42\x08\n\x06\x61\x63tion\"7\n\x0fInlineButtonRow\x12$\n\x07\x62uttons\x18\x01 \x03(\x0b\x32\x13.agent.InlineButton\"6\n\x0eInlineKeyboard\x12$\n\x04rows\x18\x01 \x03(\x0b\x32\x16.agent.InlineButtonRow\"\xb2\x03\n\x0fTelegramMessage\x12\x17\n\nmessage_id\x18\x01 \x01(\tH\x01\x88\x01\x01\x12\"\n\x04text\x18\x02 \x01(\x0b\x32\x12.agent.TextContentH\x00\x12$\n\x05image\x18\x03 \x01(\x0b\x32\x13.agent.ImageContentH\x00\x12$\n\x05video\x18\x04 \x01(\x0b\x32\x13.agent.VideoContentH\x00\x12$\n\x05\x61udio\x18\x05 \x01(\x0b\x32\x13.agent.AudioContentH\x00\x12*\n\x08\x64ocument\x18\x06 \x01(\x0b\x32\x16.agent.DocumentContentH\x00\x12*\n\x08location\x18\x07 \x01(\x0b\x32\x16.agent.LocationContentH\x00\x12\x33\n\x0finline_keyboard\x18\x08 \x01(\x0b\x32\x15.agent.InlineKeyboardH\x02\x88\x01\x01\x12*\n\x06\x61\x63tion\x18\n \x01(\x0e\x32\x15.agent.TelegramActionH\x03\x88\x01\x01\x42\t\n\x07\x63ontentB\r\n\x0b_message_idB\x12\n\x10_inline_keyboardB\t\n\x07_action\"X\n\rCallbackQuery\x12\x15\n\rcallback_data\x18\x01 \x01(\t\x12\x30\n\x10original_message\x18\x02 \x01(\x0b\x32\x16.agent.TelegramMessage\"@\n\x0cReplyMessage\x12\x30\n\x10original_message\x18\x01 \x01(\x0b\x32\x16.agent.TelegramMessage\"\xfe\x01\n\x0e\x43ontextMessage\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x11\n\x04name\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0ctool_call_id\x18\x05 \x01(\tH\x01\x88\x01\x01\x12+\n\ntool_calls\x18\x06 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\rfunction_call\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x0f\n\r_tool_call_idB\x10\n\x0e_function_call\"\xbc\x01\n\x07\x43ontext\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x03\x12\'\n\x08messages\x18\x02 \x03(\x0b\x32\x15.agent.ContextMessage\x12.\n\x08metadata\x18\x03 \x03(\x0b\x32\x1c.agent.Context.MetadataEntry\x1aG\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"4\n\x13UsagePaymentRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08quantity\x18\x02 \x01(\x03\"\x81\x03\n\x0c\x41gentRequest\x12\x35\n\x10telegram_message\x18\x01 \x01(\x0b\x32\x16.agent.TelegramMessageH\x00\x88\x01\x01\x12\x31\n\x0e\x63\x61llback_query\x18\x02 \x01(\x0b\x32\x14.agent.CallbackQueryH\x01\x88\x01\x01\x12/\n\rreply_message\x18\x03 \x01(\x0b\x32\x13.agent.ReplyMessageH\x02\x88\x01\x01\x12$\n\x07\x63ontext\x18\x04 \x01(\x0b\x32\x0e.agent.ContextH\x03\x88\x01\x01\x12\x11\n\x04paid\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rlanguage_code\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x14\n\x07user_id\x18\x08 \x01(\x03H\x06\x88\x01\x01\x42\x13\n\x11_telegram_messageB\x11\n\x0f_callback_queryB\x10\n\x0e_reply_messageB\n\n\x08_contextB\x07\n\x05_paidB\x10\n\x0e_language_codeB\n\n\x08_user_id\"\xe0\x01\n\rAgentResponse\x12\x35\n\x10telegram_message\x18\x01 \x01(\x0b\x32\x16.agent.TelegramMessageH\x00\x88\x01\x01\x12\x38\n\x0fpayment_request\x18\x02 \x01(\x0b\x32\x1a.agent.UsagePaymentRequestH\x01\x88\x01\x01\x12*\n\x06memory\x18\x04 \x01(\x0b\x32\x15.agent.ContextMessageH\x02\x88\x01\x01\x42\x13\n\x11_telegram_messageB\x12\n\x10_payment_requestB\t\n\x07_memory*\xca\x01\n\x0eTelegramAction\x12\x12\n\x0eUNKNOWN_ACTION\x10\x00\x12\n\n\x06TYPING\x10\x01\x12\x13\n\x0fUPLOADING_PHOTO\x10\x02\x12\x13\n\x0fUPLOADING_VIDEO\x10\x03\x12\x16\n\x12UPLOADING_DOCUMENT\x10\x04\x12\x13\n\x0fUPLOADING_AUDIO\x10\x05\x12\x13\n\x0fRECORDING_VIDEO\x10\x06\x12\x13\n\x0fRECORDING_AUDIO\x10\x07\x12\x17\n\x13UPLOADING_ANIMATION\x10\x08\x32\xb9\x01\n\x0c\x41gentService\x12\x33\n\x04Help\x12\x13.agent.AgentRequest\x1a\x14.agent.AgentResponse0\x01\x12\x34\n\x07\x45xecute\x12\x13.agent.AgentRequest\x1a\x14.agent.AgentResponse\x12>\n\rExecuteStream\x12\x13.agent.AgentRequest\x1a\x14.agent.AgentResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CONTEXT_METADATAENTRY']._loaded_options = None
  _globals['_CONTEXT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TELEGRAMACTION']._serialized_start=2399
  _globals['_TELEGRAMACTION']._serialized_end=2601
  _globals['_TEXTCONTENT']._serialized_start=52
  _globals['_TEXTCONTENT']._serialized_end=79
  _globals['_IMAGECONTENT']._serialized_start=81
  _globals['_IMAGECONTENT']._serialized_end=185
  _globals['_VIDEOCONTENT']._serialized_start=187
  _globals['_VIDEOCONTENT']._serialized_end=291
  _globals['_AUDIOCONTENT']._serialized_start=293
  _globals['_AUDIOCONTENT']._serialized_end=363
  _globals['_DOCUMENTCONTENT']._serialized_start=365
  _globals['_DOCUMENTCONTENT']._serialized_end=437
  _globals['_LOCATIONCONTENT']._serialized_start=439
  _globals['_LOCATIONCONTENT']._serialized_end=493
  _globals['_INLINEBUTTON']._serialized_start=495
  _globals['_INLINEBUTTON']._serialized_end=573
  _globals['_INLINEBUTTONROW']._serialized_start=575
  _globals['_INLINEBUTTONROW']._serialized_end=630
  _globals['_INLINEKEYBOARD']._serialized_start=632
  _globals['_INLINEKEYBOARD']._serialized_end=686
  _globals['_TELEGRAMMESSAGE']._serialized_start=689
  _globals['_TELEGRAMMESSAGE']._serialized_end=1123
  _globals['_CALLBACKQUERY']._serialized_start=1125
  _globals['_CALLBACKQUERY']._serialized_end=1213
  _globals['_REPLYMESSAGE']._serialized_start=1215
  _globals['_REPLYMESSAGE']._serialized_end=1279
  _globals['_CONTEXTMESSAGE']._serialized_start=1282
  _globals['_CONTEXTMESSAGE']._serialized_end=1536
  _globals['_CONTEXT']._serialized_start=1539
  _globals['_CONTEXT']._serialized_end=1727
  _globals['_CONTEXT_METADATAENTRY']._serialized_start=1656
  _globals['_CONTEXT_METADATAENTRY']._serialized_end=1727
  _globals['_USAGEPAYMENTREQUEST']._serialized_start=1729
  _globals['_USAGEPAYMENTREQUEST']._serialized_end=1781
  _globals['_AGENTREQUEST']._serialized_start=1784
  _globals['_AGENTREQUEST']._serialized_end=2169
  _globals['_AGENTRESPONSE']._serialized_start=2172
  _globals['_AGENTRESPONSE']._serialized_end=2396
  _globals['_AGENTSERVICE']._serialized_start=2604
  _globals['_AGENTSERVICE']._serialized_end=2789
# @@protoc_insertion_point(module_scope)
